Module render

Module render 

Read-only derived views over catalog, ownership, routing, and navigation. Implementation of read-only derived render views.

Render exposes compact summaries over configured catalog, ownership, routing, navigation, and workspace context without creating a new source of truth.

Structs

CatalogRepoSummary
CatalogSummary
CatalogSummaryReport
NavigationAdvisoryDoc
NavigationGovernedDoc
NavigationSummary
NavigationSummaryReport
OwnershipConflictSummary
OwnershipDomainSummary
OwnershipOverlapSummary
OwnershipSummary
OwnershipSummaryReport
RoutingIntentSummary
RoutingSummary
RoutingSummaryReport
WorkspaceRepoSummary
WorkspaceSummary
WorkspaceSummaryReport

Enums

RenderReport

Constants

RENDER_SCHEMA_VERSION

Functions

execute
run